================
etlstat modules
================

text module
-----------

Provides functions to parse different text files (normalizing columns, replacing URLs, etc.)

testing
-------
Data files are provided in order to allow execute and pass the unit tests in any development environment, including Travis builds.